@@ -83,7 +83,7 @@ QString LocationListModel::nameForListIndex(int listIndex) const
     return QString();
 }
 
-void LocationListModel::searchLocations(const QString &searchString)
+void LocationListModel::searchLocations(const QString &searchString, const QStringList& services)
 {
     m_checkedInCount = 0;
 
@@ -109,24 +109,28 @@ void LocationListModel::searchLocations(const QString &searchString)
 
     Plasma::DataEngine* dataengine = dataEngine(QStringLiteral("weather"));
 
-    const QVariantList plugins = dataengine->containerForSource(QLatin1String("ions"))->data().values();
-    foreach (const QVariant& plugin, plugins) {
+    const QVariantList plugins = dataengine->containerForSource(QStringLiteral("ions"))->data().values();
+    for (const QVariant& plugin : plugins) {
         const QStringList pluginInfo = plugin.toString().split(QLatin1Char('|'));
         if (pluginInfo.count() > 1) {
+            const QString& ionId = pluginInfo[1];
+            if (!services.contains(ionId)) {
+                continue;
+            }
             //qDebug() << "ion: " << pluginInfo[0] << pluginInfo[1];
             //d->ions.insert(pluginInfo[1], pluginInfo[0]);
 
-            WeatherValidator *validator = new WeatherValidator(this);
-            connect(validator, &WeatherValidator::error, this, &LocationListModel::validatorError);
-            connect(validator, &WeatherValidator::finished, this, &LocationListModel::addSources);
+            auto* validator = new Plasma::WeatherValidator(this);
+            connect(validator, &Plasma::WeatherValidator::error, this, &LocationListModel::validatorError);
+            connect(validator, &Plasma::WeatherValidator::finished, this, &LocationListModel::addSources);
             validator->setDataEngine(dataengine);
-            validator->setIon(pluginInfo[1]);
+            validator->setIon(ionId);
 
             m_validators.append(validator);
         }
     }
 
-    foreach (WeatherValidator *validator, m_validators) {
+    for (auto* validator : qAsConst(m_validators)) {
         validator->validate(m_searchString, true);
     }
 }
