@@ -19,6 +19,7 @@
 
 #include "abstractunitlistmodel.h"
 #include "locationlistmodel.h"
+#include "servicelistmodel.h"
 
 #include <KLocalizedString>
 
@@ -86,7 +87,7 @@ static QObject* visibilityUnitListModelSingletonTypeProvider(QQmlEngine *engine,
 
 void WeatherPlugin::registerTypes(const char *uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.weather"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.weather"));
 
     qmlRegisterSingletonType<AbstractUnitListModel>(uri, 1, 0, "TemperatureUnitListModel",
                                                     temperatureUnitListModelSingletonTypeProvider);
@@ -97,4 +98,5 @@ void WeatherPlugin::registerTypes(const char *uri)
     qmlRegisterSingletonType<AbstractUnitListModel>(uri, 1, 0, "VisibilityUnitListModel",
                                                     visibilityUnitListModelSingletonTypeProvider);
     qmlRegisterType<LocationListModel>(uri, 1, 0, "LocationListModel");
+    qmlRegisterType<ServiceListModel>(uri, 1, 0, "ServiceListModel");
 }
