@@ -26,7 +26,7 @@ class WeatherPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    void registerTypes(const char *uri);
+    void registerTypes(const char *uri) Q_DECL_OVERRIDE;
 };
 
 #endif // PLUGIN_H
