@@ -23,6 +23,7 @@
 
 #include <KLocalizedString>
 #include <KIconLoader>
+#include <KConfigGroup>
 #include <KUnitConversion/Value>
 
 #include <Plasma/Package>
@@ -36,6 +37,32 @@ T clampValue(T value, int decimals)
     return int(value * mul) / mul;
 }
 
+namespace {
+namespace AppletConfigKeys {
+inline QString services()                     { return QStringLiteral("services"); }
+inline QString showTemperatureInCompactMode() { return QStringLiteral("showTemperatureInCompactMode"); }
+}
+namespace StorageConfigKeys {
+const char weatherServiceProviders[] =      "weatherServiceProviders";
+const char showTemperatureInCompactMode[] = "showTemperatureInCompactMode";
+}
+namespace PanelModelKeys {
+inline QString location()                  { return QStringLiteral("location"); }
+inline QString currentDayLowTemperature()  { return QStringLiteral("currentDayLowTemperature"); }
+inline QString currentDayHighTemperature() { return QStringLiteral("currentDayHighTemperature"); }
+inline QString currentConditions()         { return QStringLiteral("currentConditions"); }
+inline QString currentTemperature()        { return QStringLiteral("currentTemperature"); }
+inline QString currentConditionIcon()      { return QStringLiteral("currentConditionIcon"); }
+inline QString totalDays()                 { return QStringLiteral("totalDays"); }
+inline QString courtesy()                  { return QStringLiteral("courtesy"); }
+inline QString creditUrl()                 { return QStringLiteral("creditUrl"); }
+}
+namespace NoticesKeys {
+inline QString description() { return QStringLiteral("description"); }
+inline QString info()        { return QStringLiteral("info"); }
+}
+}
+
 /**
  * Returns the @p iconName if the current icon theme contains an icon with that name,
  * otherwise returns "weather-not-available" (expecting the icon theme to have that in any case).
@@ -44,13 +71,13 @@ QString existingWeatherIconName(const QString &iconName)
 {
     const bool isValid = !iconName.isEmpty() &&
            !KIconLoader::global()->loadIcon(iconName, KIconLoader::Desktop, 0,
-                                            KIconLoader::DefaultState, QStringList(), 0, true).isNull();
+                                            KIconLoader::DefaultState, QStringList(), nullptr, true).isNull();
     return isValid ? iconName : QStringLiteral("weather-not-available");
 }
 
 
 WeatherApplet::WeatherApplet(QObject *parent, const QVariantList &args)
-        : WeatherPopupApplet(parent, args)
+    : Plasma::WeatherPopupApplet(parent, args)
 {
 }
 
@@ -58,40 +85,45 @@ void WeatherApplet::init()
 {
     resetPanelModel();
 
-    WeatherPopupApplet::init();
+    Plasma::WeatherPopupApplet::init();
+}
+
+void WeatherApplet::configChanged()
+{
+    Plasma::WeatherPopupApplet::WeatherPopupApplet::configChanged();
+
+    KConfigGroup cfg = config();
+
+    m_configuration.insert(AppletConfigKeys::showTemperatureInCompactMode(),
+                           cfg.readEntry(StorageConfigKeys::showTemperatureInCompactMode, false));
+    emit configurationChanged();
 }
 
 WeatherApplet::~WeatherApplet()
 {
 }
 
-QString WeatherApplet::convertTemperature(KUnitConversion::Unit format, const QVariant &value,
+QString WeatherApplet::convertTemperature(const KUnitConversion::Unit& format, const QVariant& value,
                                           int type, bool rounded, bool degreesOnly)
 {
     return convertTemperature(format, value.toFloat(), type, rounded, degreesOnly);
 }
 
-QString WeatherApplet::convertTemperature(KUnitConversion::Unit format, float value,
+QString WeatherApplet::convertTemperature(const KUnitConversion::Unit& format, float value,
                                           int type, bool rounded, bool degreesOnly)
 {
     KUnitConversion::Value v(value, static_cast<KUnitConversion::UnitId>(type));
     v = v.convertTo(format);
 
+    const QString unit = degreesOnly ? i18nc("Degree, unit symbol", "°") : v.unit().symbol();
+
     if (rounded) {
         int tempNumber = qRound(v.number());
-        if (degreesOnly) {
-            return i18nc("temperature, unit", "%1%2", tempNumber, i18nc("Degree, unit symbol", "°"));
-        } else {
-            return i18nc("temperature, unit", "%1%2", tempNumber, v.unit().symbol());
-        }
-    } else {
-        const QString formattedTemp = QLocale().toString(clampValue(v.number(), 1), 'f', 1);
-        if (degreesOnly) {
-            return i18nc("temperature, unit", "%1%2", formattedTemp, i18nc("Degree, unit symbol", "°"));
-        } else {
-            return i18nc("temperature, unit", "%1%2", formattedTemp, v.unit().symbol());
-        }
+        return i18nc("temperature, unit", "%1%2", tempNumber, unit);
     }
+
+    const QString formattedTemp = QLocale().toString(clampValue(v.number(), 1), 'f', 1);
+    return i18nc("temperature, unit", "%1%2", formattedTemp, unit);
 }
 
 bool WeatherApplet::isValidData(const QString &data) const
@@ -106,52 +138,52 @@ bool WeatherApplet::isValidData(const QVariant &data) const
 
 void WeatherApplet::resetPanelModel()
 {
-    m_panelModel["location"] = "";
-    m_panelModel["currentDayLowTemperature"] = "";
-    m_panelModel["currentDayHighTemperature"] = "";
-    m_panelModel["currentConditions"] = "";
-    m_panelModel["currentTemperature"] = "";
-    m_panelModel["currentConditionIcon"] = "";
-    m_panelModel["totalDays"] = "";
-    m_panelModel["courtesy"] = "";
-    m_panelModel["creditUrl"] = "";
+    m_panelModel[PanelModelKeys::location()] = QString();
+    m_panelModel[PanelModelKeys::currentDayLowTemperature()] = QString();
+    m_panelModel[PanelModelKeys::currentDayHighTemperature()] = QString();
+    m_panelModel[PanelModelKeys::currentConditions()] = QString();
+    m_panelModel[PanelModelKeys::currentTemperature()] = QString();
+    m_panelModel[PanelModelKeys::currentConditionIcon()] = QString();
+    m_panelModel[PanelModelKeys::totalDays()] = QString();
+    m_panelModel[PanelModelKeys::courtesy()] = QString();
+    m_panelModel[PanelModelKeys::creditUrl()] = QString();
 }
 
 void WeatherApplet::updatePanelModel(const Plasma::DataEngine::Data &data)
 {
     resetPanelModel();
 
-    m_panelModel["location"] = data["Place"].toString();
+    m_panelModel[PanelModelKeys::location()] = data[QStringLiteral("Place")].toString();
 
-    const int reportTemperatureUnit = data["Temperature Unit"].toInt();
+    const int reportTemperatureUnit = data[QStringLiteral("Temperature Unit")].toInt();
     const KUnitConversion::Unit displayTemperatureUnit = temperatureUnit();
 
     // Get current time period of day
-    const QStringList fiveDayTokens = data["Short Forecast Day 0"].toString().split(QLatin1Char('|'));
+    const QStringList fiveDayTokens = data[QStringLiteral("Short Forecast Day 0")].toString().split(QLatin1Char('|'));
 
     if (fiveDayTokens.count() == 6) {
 
         const QString& reportLowString = fiveDayTokens[4];
         if (reportLowString != QLatin1String("N/A") && !reportLowString.isEmpty()) {
-            m_panelModel["currentDayLowTemperature"] =
+            m_panelModel[PanelModelKeys::currentDayLowTemperature()] =
                 convertTemperature(displayTemperatureUnit, reportLowString, reportTemperatureUnit, true);
         }
 
         const QString& reportHighString = fiveDayTokens[3];
         if (reportHighString != QLatin1String("N/A") && !reportHighString.isEmpty()) {
-            m_panelModel["currentDayHighTemperature"] =
+            m_panelModel[PanelModelKeys::currentDayHighTemperature()] =
                 convertTemperature(displayTemperatureUnit, reportHighString, reportTemperatureUnit, true);
         }
     }
 
-    m_panelModel["currentConditions"] = data["Current Conditions"].toString().trimmed();
+    m_panelModel[PanelModelKeys::currentConditions()] = data[QStringLiteral("Current Conditions")].toString().trimmed();
 
     const QVariant temperature = data[QStringLiteral("Temperature")];
     if (isValidData(temperature)) {
-        m_panelModel["currentTemperature"] = convertTemperature(displayTemperatureUnit, temperature, reportTemperatureUnit);
+        m_panelModel[PanelModelKeys::currentTemperature()] = convertTemperature(displayTemperatureUnit, temperature, reportTemperatureUnit);
     }
 
-    const QString conditionIconName = data["Condition Icon"].toString();
+    const QString conditionIconName = data[QStringLiteral("Condition Icon")].toString();
     QString weatherIconName;
     // specific icon?
     if (!conditionIconName.isEmpty() &&
@@ -169,10 +201,10 @@ void WeatherApplet::updatePanelModel(const Plasma::DataEngine::Data &data)
             weatherIconName = QStringLiteral("weather-none-available");
         }
     }
-    m_panelModel["currentConditionIcon"] = weatherIconName;
+    m_panelModel[PanelModelKeys::currentConditionIcon()] = weatherIconName;
 
-    m_panelModel["courtesy"] = data["Credit"].toString();
-    m_panelModel["creditUrl"] = data["Credit Url"].toString();
+    m_panelModel[PanelModelKeys::courtesy()] =  data[QStringLiteral("Credit")].toString();
+    m_panelModel[PanelModelKeys::creditUrl()] = data[QStringLiteral("Credit Url")].toString();
 }
 
 void WeatherApplet::updateFiveDaysModel(const Plasma::DataEngine::Data &data)
@@ -261,8 +293,8 @@ void WeatherApplet::updateFiveDaysModel(const Plasma::DataEngine::Data &data)
         m_fiveDaysModel << lowItems;
     }
 
-    m_panelModel["totalDays"] = i18ncp("Forecast period timeframe", "1 Day",
-                                       "%1 Days", foreCastDayCount);
+    m_panelModel[PanelModelKeys::totalDays()] = i18ncp("Forecast period timeframe", "1 Day",
+                                                       "%1 Days", foreCastDayCount);
 }
 
 void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
@@ -313,7 +345,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
     const QVariant pressure = data[QStringLiteral("Pressure")];
     if (isValidData(pressure)) {
         KUnitConversion::Value v(pressure.toDouble(),
-                                 static_cast<KUnitConversion::UnitId>(data["Pressure Unit"].toInt()));
+                                 static_cast<KUnitConversion::UnitId>(data[QStringLiteral("Pressure Unit")].toInt()));
         v = v.convertTo(pressureUnit());
         row[textId] = i18nc("pressure, unit","Pressure: %1 %2",
                             locale.toString(clampValue(v.number(), 2), 'f', 2), v.unit().symbol());
@@ -321,7 +353,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
         m_detailsModel << row;
     }
 
-    const QString pressureTendency = data["Pressure Tendency"].toString();
+    const QString pressureTendency = data[QStringLiteral("Pressure Tendency")].toString();
     if (isValidData(pressureTendency)) {
         const QString i18nPressureTendency = i18nc("pressure tendency", pressureTendency.toUtf8().data());
         row[textId] = i18nc("pressure tendency, rising/falling/steady",
@@ -332,7 +364,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
 
     const QVariant visibility = data[QStringLiteral("Visibility")];
     if (isValidData(visibility)) {
-        const KUnitConversion::UnitId unitId = static_cast<KUnitConversion::UnitId>(data["Visibility Unit"].toInt());
+        const KUnitConversion::UnitId unitId = static_cast<KUnitConversion::UnitId>(data[QStringLiteral("Visibility Unit")].toInt());
         if (unitId != KUnitConversion::NoUnit) {
             KUnitConversion::Value v(visibility.toDouble(), unitId);
             v = v.convertTo(visibilityUnit());
@@ -356,7 +388,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
     const QVariant windSpeed = data[QStringLiteral("Wind Speed")];
     if (isValidData(windSpeed)) {
         // TODO: missing check for windDirection validness
-        const QString windDirection = data["Wind Direction"].toString();
+        const QString windDirection = data[QStringLiteral("Wind Direction")].toString();
         row[iconId] = windDirection;
 
         bool isNumeric;
@@ -364,7 +396,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
         if (isNumeric) {
             if (windSpeedNumeric != 0) {
                 KUnitConversion::Value v(windSpeedNumeric,
-                                        static_cast<KUnitConversion::UnitId>(data["Wind Speed Unit"].toInt()));
+                                        static_cast<KUnitConversion::UnitId>(data[QStringLiteral("Wind Speed Unit")].toInt()));
                 v = v.convertTo(speedUnit());
                 const QString i18nWindDirection = i18nc("wind direction", windDirection.toUtf8().data());
                 row[textId] = i18nc("wind direction, speed","%1 %2 %3", i18nWindDirection,
@@ -384,7 +416,7 @@ void WeatherApplet::updateDetailsModel(const Plasma::DataEngine::Data &data)
     if (isValidData(windGust)) {
         // Convert the wind format for nonstandard types
         KUnitConversion::Value v(windGust.toDouble(),
-                                 static_cast<KUnitConversion::UnitId>(data["Wind Speed Unit"].toInt()));
+                                 static_cast<KUnitConversion::UnitId>(data[QStringLiteral("Wind Speed Unit")].toInt()));
         v = v.convertTo(speedUnit());
         row[textId] = i18nc("winds exceeding wind speed briefly", "Wind Gust: %1 %2",
                             locale.toString(clampValue(v.number(), 1), 'f', 1), v.unit().symbol());
@@ -398,20 +430,24 @@ void WeatherApplet::updateNoticesModel(const Plasma::DataEngine::Data &data)
     m_noticesModel.clear();
 
     QVariantList warnings;
-    for (int i = 0; i < data["Total Warnings Issued"].toInt(); ++i) {
-        QVariantMap warning;
-        warning["description"] = data[QStringLiteral("Warning Description %1").arg(i)];
-        warning["info"] = data[QStringLiteral("Warning Info %1").arg(i)];
-        warnings << warning;
+    const int warningsCount = data[QStringLiteral("Total Warnings Issued")].toInt();
+    warnings.reserve(warningsCount);
+    for (int i = 0; i < warningsCount; ++i) {
+        warnings << QVariantMap {
+            { NoticesKeys::description(), data[QStringLiteral("Warning Description %1").arg(i)] },
+            { NoticesKeys::info(),        data[QStringLiteral("Warning Info %1").arg(i)] },
+        };
     }
     m_noticesModel << QVariant(warnings);
 
     QVariantList watches;
-    for (int i = 0; i < data["Total Watches Issued"].toInt(); ++i) {
-        QVariantMap watch;
-        watch["description"] = data[QStringLiteral("Watch Description %1").arg(i)];
-        watch["info"] = data[QStringLiteral("Watch Info %1").arg(i)];
-        watches << watch;
+    const int watchesCount = data[QStringLiteral("Total Watches Issued")].toInt();
+    watches.reserve(watchesCount);
+    for (int i = 0; i < watchesCount; ++i) {
+        watches << QVariantMap {
+            { NoticesKeys::description(), data[QStringLiteral("Watch Description %1").arg(i)] },
+            { NoticesKeys::info(),        data[QStringLiteral("Watch Info %1").arg(i)] },
+        };
     }
     m_noticesModel << QVariant(watches);
 }
@@ -431,6 +467,17 @@ void WeatherApplet::dataUpdated(const QString &source, const Plasma::DataEngine:
     emit modelUpdated();
 }
 
+QVariantMap WeatherApplet::configValues() const
+{
+    QVariantMap config = WeatherPopupApplet::configValues();
+
+    KConfigGroup cfg = this->config();
+    config.insert(AppletConfigKeys::services(), cfg.readEntry(StorageConfigKeys::weatherServiceProviders, QStringList()));
+    config.insert(AppletConfigKeys::showTemperatureInCompactMode(), cfg.readEntry(StorageConfigKeys::showTemperatureInCompactMode, false));
+
+    return config;
+}
+
 void WeatherApplet::saveConfig(const QVariantMap& configChanges)
 {
     // TODO: if just units where changed there is no need to reset the complete model or reconnect to engine
@@ -440,6 +487,17 @@ void WeatherApplet::saveConfig(const QVariantMap& configChanges)
 
     emit modelUpdated();
 
+    KConfigGroup cfg = config();
+
+    auto it = configChanges.find(AppletConfigKeys::services());
+    if (it != configChanges.end()) {
+        cfg.writeEntry(StorageConfigKeys::weatherServiceProviders, it.value().toStringList());
+    }
+    it = configChanges.find(AppletConfigKeys::showTemperatureInCompactMode());
+    if (it != configChanges.end()) {
+        cfg.writeEntry(StorageConfigKeys::showTemperatureInCompactMode, it.value().toBool());
+    }
+
     WeatherPopupApplet::saveConfig(configChanges);
 }
 
