@@ -28,6 +28,7 @@
 
 #include "plasmaweather_export.h"
 
+namespace Plasma {
 
 /**
  * @class WeatherPopupApplet <plasmaweather/weatherpopupapplet.h>
@@ -110,12 +111,11 @@ class PLASMAWEATHER_EXPORT WeatherPopupApplet : public Plasma::Applet, public Pl
         void connectToEngine();
 
     private:
-        class Private;
-        Private * const d;
+        const QScopedPointer<class WeatherPopupAppletPrivate> d;
 
-        Q_PRIVATE_SLOT(d, void locationReady(const QString &source))
-        Q_PRIVATE_SLOT(d, void giveUpBeingBusy())
-        Q_PRIVATE_SLOT(d, void onTimeoutNotificationClosed())
+        friend class WeatherPopupAppletPrivate;
 };
 
+}
+
 #endif
