@@ -24,6 +24,8 @@
 
 #include "plasmaweather_export.h"
 
+namespace Plasma {
+
 /**
  * @class WeatherValidator <plasmaweather/weathervalidator.h>
  *
@@ -34,7 +36,7 @@ class PLASMAWEATHER_EXPORT WeatherValidator : public QObject
     Q_OBJECT
 public:
     explicit WeatherValidator(QObject *parent = nullptr);
-    virtual ~WeatherValidator();
+    ~WeatherValidator() override;
 
     /**
      * Validate location 
@@ -87,8 +89,9 @@ public Q_SLOTS:
     void dataUpdated(const QString &source, const Plasma::DataEngine::Data &data);
 
 private:
-    class Private;
-    Private * const d;
+    const QScopedPointer<class WeatherValidatorPrivate> d;
 };
 
+}
+
 #endif
